@@ -1,4 +1,4 @@
-#include <slang/slang.h>
+#include <slang.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -7,7 +7,6 @@
 
 struct button {
     char * text;
-    char bgColor;
     int compact;
 };
 
@@ -18,13 +17,14 @@ static void buttonDraw(newtComponent c);
 static void buttonDestroy(newtComponent co);
 static struct eventResult buttonEvent(newtComponent c,
 				      struct event ev);
-static void buttonPlace(newtComponent co);
+static void buttonPlace(newtComponent co, int newLeft, int newTop);
 
 static struct componentOps buttonOps = {
     buttonDraw,
     buttonEvent,
     buttonDestroy,
     buttonPlace,
+    newtDefaultMappedHandler,
 } ;
 
 static newtComponent createButton(int left, int row, const char * text, int compact) {
@@ -50,9 +50,9 @@ static newtComponent createButton(int left, int row, const char * text, int comp
     co->top = row;
     co->left = left;
     co->takesFocus = 1;
+    co->isMapped = 0;
 
     newtGotorc(co->top, co->left);
-    bu->bgColor = -1;
 
     return co;
 }
@@ -73,11 +73,11 @@ static void buttonDestroy(newtComponent co) {
     free(co);
 }
 
-static void buttonPlace(newtComponent co) {
-    struct button * bu = co->data;
+static void buttonPlace(newtComponent co, int newLeft, int newTop) {
+    co->top = newTop;
+    co->left = newLeft;
 
     newtGotorc(co->top, co->left);
-    bu->bgColor = (SLsmg_char_at() >> 8) & 0xFF;
 }
 
 static void buttonDraw(newtComponent co) {
@@ -87,15 +87,12 @@ static void buttonDraw(newtComponent co) {
 static void buttonDrawIt(newtComponent co, int active, int pushed) {
     struct button * bu = co->data;
 
-    if (bu->bgColor == -1) {
-	newtGotorc(co->top, co->left);
-	bu->bgColor = (SLsmg_char_at() >> 8) & 0xFF;
-    }
+    if (!co->isMapped) return;
 
     SLsmg_set_color(NEWT_COLORSET_BUTTON);
 
     if (bu->compact) {
-	if (active) 
+	if (active)
 	    SLsmg_set_color(NEWT_COLORSET_COMPACTBUTTON);
 	else
 	    SLsmg_set_color(NEWT_COLORSET_BUTTON);
@@ -108,7 +105,7 @@ static void buttonDrawIt(newtComponent co, int active, int pushed) {
 	    SLsmg_set_color(NEWT_COLORSET_BUTTON);
 	    newtDrawBox(co->left + 1, co->top + 1, co->width - 1, 3, 0);
 
-	    SLsmg_set_color(bu->bgColor);
+	    SLsmg_set_color(NEWT_COLORSET_WINDOW);
 	    newtClearBox(co->left, co->top, co->width, 1);
 	    newtClearBox(co->left, co->top, 1, co->height);
 	} else {
@@ -165,11 +162,28 @@ static struct eventResult buttonEvent(newtComponent co,
 		}
 
 		er.result = ER_EXITFORM;
-	    } else 
+	    } else
 		er.result = ER_IGNORED;
 	    break;
+	  case EV_MOUSE:
+	      if (ev.u.mouse.type == MOUSE_BUTTON_DOWN &&
+		  co->top <= ev.u.mouse.y &&
+		  co->top + co->height - !bu->compact > ev.u.mouse.y &&
+		  co->left <= ev.u.mouse.x &&
+		  co->left + co->width - !bu->compact > ev.u.mouse.x) {
+		  if (!bu->compact) {
+		      buttonDrawIt(co, 1, 1);
+		      newtRefresh();
+		      newtDelay(150000);
+		      buttonDrawIt(co, 1, 0);
+		      newtRefresh();
+		      newtDelay(150000);
+		  }
+		  er.result = ER_EXITFORM;
+	      }
+	    break;
 	}
-    } else 
+    } else
 	er.result = ER_IGNORED;
 
     return er;
