@@ -31,6 +31,7 @@ static char ** currentHelpline = NULL;
 
 static int cursorRow, cursorCol;
 static int needResize;
+static int cursorOn = 1;
 
 static const char * defaultHelpLine =
 "  <Tab>/<Alt-Tab> between elements   |  <Space> selects   |  <F12> next screen"
@@ -92,10 +93,10 @@ static const struct keymap keymap[] = {
 	{ "\033[[D",		NEWT_KEY_F4,		NULL },
 	{ "\033[[E",		NEWT_KEY_F5,		NULL },
 
-	{ "\033OP",		NEWT_KEY_F2,		NULL },
+	{ "\033OP",		NEWT_KEY_F1,		NULL },
 	{ "\033OQ",		NEWT_KEY_F2,		NULL },
-	{ "\033OR",		NEWT_KEY_F2,		NULL },
-	{ "\033OS",		NEWT_KEY_F2,		NULL },
+	{ "\033OR",		NEWT_KEY_F3,		NULL },
+	{ "\033OS",		NEWT_KEY_F4,		NULL },
 
 	{ "\033[11~",		NEWT_KEY_F1,		NULL },
 	{ "\033[12~",		NEWT_KEY_F2,		NULL },
@@ -115,7 +116,7 @@ static const struct keymap keymap[] = {
 static char keyPrefix = '\033';
 
 static const char * version = "Newt windowing library version " VERSION
-			" - (C) 1996 Red Hat Software. "
+			" - (C) 1996-2000 Red Hat Software. "
 		        "Redistributable under the term of the Library "
 		        "GNU Public License. "
 			"Written by Erik Troan\n";
@@ -147,8 +148,10 @@ void newtRefresh(void) {
 }
 
 void newtSuspend(void) {
+    SLtt_set_cursor_visibility (1);
     SLsmg_suspend_smg();
     SLang_reset_tty();
+    SLtt_set_cursor_visibility (cursorOn);
 }
 
 void newtResume(void) {
@@ -165,6 +168,7 @@ void newtCls(void) {
     newtRefresh();
 }
 
+#if defined(THIS_DOESNT_WORK)
 void newtResizeScreen(int redraw) {
     newtPushHelpLine("");
 
@@ -181,6 +185,7 @@ void newtResizeScreen(int redraw) {
     if (redraw)
 	SLsmg_refresh();
 }
+#endif
 
 int newtInit(void) {
     char * MonoValue, * MonoEnv = "NEWT_MONO";
@@ -202,10 +207,9 @@ int newtInit(void) {
     SLang_init_tty(0, 0, 0);
 
     newtSetColors(newtDefaultColorPalette);
+    newtCursorOff();
     /*initKeymap();*/
 
-    /*SLtt_set_cursor_visibility(0);*/
-
     /*memset(&sa, 0, sizeof(sa));
     sa.sa_handler = handleSigwinch;
     sigaction(SIGWINCH, &sa, NULL);*/
@@ -220,6 +224,7 @@ int newtInit(void) {
 
 int newtFinished(void) {
     SLsmg_gotorc(SLtt_Screen_Rows - 1, 0);
+    newtCursorOn();
     SLsmg_refresh();
     SLsmg_reset_smg();
     SLang_reset_tty();
@@ -655,3 +660,13 @@ void newtDefaultPlaceHandler(newtComponent c, int newLeft, int newTop) {
 void newtDefaultMappedHandler(newtComponent c, int isMapped) {
     c->isMapped = isMapped;
 }
+
+void newtCursorOff(void) {
+    cursorOn = 0;
+    SLtt_set_cursor_visibility (cursorOn);
+}
+
+void newtCursorOn(void) {
+    cursorOn = 1;
+    SLtt_set_cursor_visibility (cursorOn);
+}
